@@ -13,13 +13,14 @@ class Config:
     doubleclick: bool = False               # Require double-click of hotkey to trigger
     doubleclick_window: float = 0.5         # Double-click activation window (seconds)
     cooldown: float = 2.0                   # Trigger cooldown
-    sound: bool = True                      # Play sound when triggered
+    sound: bool = False                     # Play sound when triggered
     mute_sound: str = "audio/muted.wav"     # Mute sound
     unmute_sound: str = "audio/unmuted.wav" # Unmute sound
 
     def __post_init__(self) -> None:
-        self.mute_sound = parse_sound_path(self.mute_sound)
-        self.unmute_sound = parse_sound_path(self.unmute_sound)
+        if self.sound:
+            self.mute_sound = parse_sound_path(self.mute_sound)
+            self.unmute_sound = parse_sound_path(self.unmute_sound)
 
 
 def parse_sound_path(path: str) -> str:
